@@ -3,6 +3,7 @@ use strict;
 use warnings;
 use base qw/Pod::Parser Class::Accessor::Fast Class::Data::Inheritable/;
 use Pod::ParseUtils;
+use URI::Escape;
 use File::Spec;
 use File::Basename;
 use Pod::ProjectDocs::Template;
@@ -635,7 +636,11 @@ sub _prepare {
     $self->addHeadText($components->{css}->tag($doc));
     $self->addHeadText(qq|<meta http-equiv="Content-Type" content="text/html; charset=$charset" />\n|);
     $self->addBodyOpenText($self->_get_data($doc, $mgr_desc));
-	$self->addBodyCloseText(qq|<div class="footer">generated by <a href="http://search.cpan.org/~lyokato/Pod-ProjectDocs/">Pod::ProjectDocs</a></div>|);
+	$self->addBodyCloseText(
+        qq|<div class="footer">generated by <a href="http://search.cpan.org/perldoc?|
+        .URI::Escape::uri_escape("Pod::ProjectDocs")
+        .qq|">Pod::ProjectDocs</a></div>|
+    );
 }
 
 sub _get_title {
